# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V42
6917
6964
6981
6989
43396
43443
69637
69688
69745
69747
69749
69750
70405
70413
70415
70417
70419
70441
70442
70449
70450
70452
70453
70458
70496
70498
70546
70582
71936
71943
71945
71946
71948
71956
71957
71959
71960
71984
73476
73489
73490
73524
END
