+{
   locale_version => 1.31,
   entry => <<'ENTRY', # for DUCET v13.0.0
0491      ; [.239C.0020.0002] # CYRILLIC SMALL LETTER GHE WITH UPTURN
0490      ; [.239C.0020.0008] # CYRILLIC CAPITAL LETTER GHE WITH UPTURN
A647      ; [.23EE.0020.0002] # CYRILLIC SMALL LETTER IOTA
A646      ; [.23EE.0020.0008] # CYRILLIC CAPITAL LETTER IOTA
0457      ; [.23EF.0020.0002] # CYRILLIC SMALL LETTER YI
0456 0308 ; [.23EF.0020.0002] # CYRILLIC SMALL LETTER YI
0407      ; [.23EF.0020.0008] # CYRILLIC CAPITAL LETTER YI
0406 0308 ; [.23EF.0020.0008] # CYRILLIC CAPITAL LETTER YI
A676      ; [.23EF.0020.0004] # COMBINING CYRILLIC LETTER YI
ENTRY
};
