# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToInCB'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToInCB'}{'missing'} = 'None';

return <<'END';
300	36F	Extend
483	489	Extend
591	5BD	Extend
5BF		Extend
5C1	5C2	Extend
5C4	5C5	Extend
5C7		Extend
610	61A	Extend
64B	65F	Extend
670		Extend
6D6	6DC	Extend
6DF	6E4	Extend
6E7	6E8	Extend
6EA	6ED	Extend
711		Extend
730	74A	Extend
7A6	7B0	Extend
7EB	7F3	Extend
7FD		Extend
816	819	Extend
81B	823	Extend
825	827	Extend
829	82D	Extend
859	85B	Extend
897	89F	Extend
8CA	8E1	Extend
8E3	902	Extend
915	939	Consonant
93A		Extend
93C		Extend
941	948	Extend
94D		Linker
951	957	Extend
958	95F	Consonant
962	963	Extend
978	97F	Consonant
981		Extend
995	9A8	Consonant
9AA	9B0	Consonant
9B2		Consonant
9B6	9B9	Consonant
9BC		Extend
9BE		Extend
9C1	9C4	Extend
9CD		Linker
9D7		Extend
9DC	9DD	Consonant
9DF		Consonant
9E2	9E3	Extend
9F0	9F1	Consonant
9FE		Extend
A01	A02	Extend
A3C		Extend
A41	A42	Extend
A47	A48	Extend
A4B	A4D	Extend
A51		Extend
A70	A71	Extend
A75		Extend
A81	A82	Extend
A95	AA8	Consonant
AAA	AB0	Consonant
AB2	AB3	Consonant
AB5	AB9	Consonant
ABC		Extend
AC1	AC5	Extend
AC7	AC8	Extend
ACD		Linker
AE2	AE3	Extend
AF9		Consonant
AFA	AFF	Extend
B01		Extend
B15	B28	Consonant
B2A	B30	Consonant
B32	B33	Consonant
B35	B39	Consonant
B3C		Extend
B3E	B3F	Extend
B41	B44	Extend
B4D		Linker
B55	B57	Extend
B5C	B5D	Consonant
B5F		Consonant
B62	B63	Extend
B71		Consonant
B82		Extend
BBE		Extend
BC0		Extend
BCD		Extend
BD7		Extend
C00		Extend
C04		Extend
C15	C28	Consonant
C2A	C39	Consonant
C3C		Extend
C3E	C40	Extend
C46	C48	Extend
C4A	C4C	Extend
C4D		Linker
C55	C56	Extend
C58	C5A	Consonant
C62	C63	Extend
C81		Extend
CBC		Extend
CBF	CC0	Extend
CC2		Extend
CC6	CC8	Extend
CCA	CCD	Extend
CD5	CD6	Extend
CE2	CE3	Extend
D00	D01	Extend
D15	D3A	Consonant
D3B	D3C	Extend
D3E		Extend
D41	D44	Extend
D4D		Linker
D57		Extend
D62	D63	Extend
D81		Extend
DCA		Extend
DCF		Extend
DD2	DD4	Extend
DD6		Extend
DDF		Extend
E31		Extend
E34	E3A	Extend
E47	E4E	Extend
EB1		Extend
EB4	EBC	Extend
EC8	ECE	Extend
F18	F19	Extend
F35		Extend
F37		Extend
F39		Extend
F71	F7E	Extend
F80	F84	Extend
F86	F87	Extend
F8D	F97	Extend
F99	FBC	Extend
FC6		Extend
102D	1030	Extend
1032	1037	Extend
1039	103A	Extend
103D	103E	Extend
1058	1059	Extend
105E	1060	Extend
1071	1074	Extend
1082		Extend
1085	1086	Extend
108D		Extend
109D		Extend
135D	135F	Extend
1712	1715	Extend
1732	1734	Extend
1752	1753	Extend
1772	1773	Extend
17B4	17B5	Extend
17B7	17BD	Extend
17C6		Extend
17C9	17D3	Extend
17DD		Extend
180B	180D	Extend
180F		Extend
1885	1886	Extend
18A9		Extend
1920	1922	Extend
1927	1928	Extend
1932		Extend
1939	193B	Extend
1A17	1A18	Extend
1A1B		Extend
1A56		Extend
1A58	1A5E	Extend
1A60		Extend
1A62		Extend
1A65	1A6C	Extend
1A73	1A7C	Extend
1A7F		Extend
1AB0	1ACE	Extend
1B00	1B03	Extend
1B34	1B3D	Extend
1B42	1B44	Extend
1B6B	1B73	Extend
1B80	1B81	Extend
1BA2	1BA5	Extend
1BA8	1BAD	Extend
1BE6		Extend
1BE8	1BE9	Extend
1BED		Extend
1BEF	1BF3	Extend
1C2C	1C33	Extend
1C36	1C37	Extend
1CD0	1CD2	Extend
1CD4	1CE0	Extend
1CE2	1CE8	Extend
1CED		Extend
1CF4		Extend
1CF8	1CF9	Extend
1DC0	1DFF	Extend
200D		Extend
20D0	20F0	Extend
2CEF	2CF1	Extend
2D7F		Extend
2DE0	2DFF	Extend
302A	302F	Extend
3099	309A	Extend
A66F	A672	Extend
A674	A67D	Extend
A69E	A69F	Extend
A6F0	A6F1	Extend
A802		Extend
A806		Extend
A80B		Extend
A825	A826	Extend
A82C		Extend
A8C4	A8C5	Extend
A8E0	A8F1	Extend
A8FF		Extend
A926	A92D	Extend
A947	A951	Extend
A953		Extend
A980	A982	Extend
A9B3		Extend
A9B6	A9B9	Extend
A9BC	A9BD	Extend
A9C0		Extend
A9E5		Extend
AA29	AA2E	Extend
AA31	AA32	Extend
AA35	AA36	Extend
AA43		Extend
AA4C		Extend
AA7C		Extend
AAB0		Extend
AAB2	AAB4	Extend
AAB7	AAB8	Extend
AABE	AABF	Extend
AAC1		Extend
AAEC	AAED	Extend
AAF6		Extend
ABE5		Extend
ABE8		Extend
ABED		Extend
FB1E		Extend
FE00	FE0F	Extend
FE20	FE2F	Extend
FF9E	FF9F	Extend
101FD		Extend
102E0		Extend
10376	1037A	Extend
10A01	10A03	Extend
10A05	10A06	Extend
10A0C	10A0F	Extend
10A38	10A3A	Extend
10A3F		Extend
10AE5	10AE6	Extend
10D24	10D27	Extend
10D69	10D6D	Extend
10EAB	10EAC	Extend
10EFC	10EFF	Extend
10F46	10F50	Extend
10F82	10F85	Extend
11001		Extend
11038	11046	Extend
11070		Extend
11073	11074	Extend
1107F	11081	Extend
110B3	110B6	Extend
110B9	110BA	Extend
110C2		Extend
11100	11102	Extend
11127	1112B	Extend
1112D	11134	Extend
11173		Extend
11180	11181	Extend
111B6	111BE	Extend
111C0		Extend
111C9	111CC	Extend
111CF		Extend
1122F	11231	Extend
11234	11237	Extend
1123E		Extend
11241		Extend
112DF		Extend
112E3	112EA	Extend
11300	11301	Extend
1133B	1133C	Extend
1133E		Extend
11340		Extend
1134D		Extend
11357		Extend
11366	1136C	Extend
11370	11374	Extend
113B8		Extend
113BB	113C0	Extend
113C2		Extend
113C5		Extend
113C7	113C9	Extend
113CE	113D0	Extend
113D2		Extend
113E1	113E2	Extend
11438	1143F	Extend
11442	11444	Extend
11446		Extend
1145E		Extend
114B0		Extend
114B3	114B8	Extend
114BA		Extend
114BD		Extend
114BF	114C0	Extend
114C2	114C3	Extend
115AF		Extend
115B2	115B5	Extend
115BC	115BD	Extend
115BF	115C0	Extend
115DC	115DD	Extend
11633	1163A	Extend
1163D		Extend
1163F	11640	Extend
116AB		Extend
116AD		Extend
116B0	116B7	Extend
1171D		Extend
1171F		Extend
11722	11725	Extend
11727	1172B	Extend
1182F	11837	Extend
11839	1183A	Extend
11930		Extend
1193B	1193E	Extend
11943		Extend
119D4	119D7	Extend
119DA	119DB	Extend
119E0		Extend
11A01	11A0A	Extend
11A33	11A38	Extend
11A3B	11A3E	Extend
11A47		Extend
11A51	11A56	Extend
11A59	11A5B	Extend
11A8A	11A96	Extend
11A98	11A99	Extend
11C30	11C36	Extend
11C38	11C3D	Extend
11C3F		Extend
11C92	11CA7	Extend
11CAA	11CB0	Extend
11CB2	11CB3	Extend
11CB5	11CB6	Extend
11D31	11D36	Extend
11D3A		Extend
11D3C	11D3D	Extend
11D3F	11D45	Extend
11D47		Extend
11D90	11D91	Extend
11D95		Extend
11D97		Extend
11EF3	11EF4	Extend
11F00	11F01	Extend
11F36	11F3A	Extend
11F40	11F42	Extend
11F5A		Extend
13440		Extend
13447	13455	Extend
1611E	16129	Extend
1612D	1612F	Extend
16AF0	16AF4	Extend
16B30	16B36	Extend
16F4F		Extend
16F8F	16F92	Extend
16FE4		Extend
16FF0	16FF1	Extend
1BC9D	1BC9E	Extend
1CF00	1CF2D	Extend
1CF30	1CF46	Extend
1D165	1D169	Extend
1D16D	1D172	Extend
1D17B	1D182	Extend
1D185	1D18B	Extend
1D1AA	1D1AD	Extend
1D242	1D244	Extend
1DA00	1DA36	Extend
1DA3B	1DA6C	Extend
1DA75		Extend
1DA84		Extend
1DA9B	1DA9F	Extend
1DAA1	1DAAF	Extend
1E000	1E006	Extend
1E008	1E018	Extend
1E01B	1E021	Extend
1E023	1E024	Extend
1E026	1E02A	Extend
1E08F		Extend
1E130	1E136	Extend
1E2AE		Extend
1E2EC	1E2EF	Extend
1E4EC	1E4EF	Extend
1E5EE	1E5EF	Extend
1E8D0	1E8D6	Extend
1E944	1E94A	Extend
1F3FB	1F3FF	Extend
E0020	E007F	Extend
E0100	E01EF	Extend
END
