# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 16.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V36
4981
4982
12875
12876
12981
12982
21324
21325
65811
65812
66285
66286
68044
68045
69228
69229
69726
69727
70125
70126
71917
71918
72806
72807
74855
74856
119660
119661
126077
126078
126221
126222
133516
133517
133532
133533
END
